Exception: Railsmith::Pipeline::ParamCollisionError

Inherits:
StandardError
  • Object
show all
Defined in:
lib/railsmith/pipeline/errors.rb

Overview

Raised when a step’s Hash result.value would overwrite an existing accumulated param key with a different value.

Instance Method Summary collapse

Constructor Details

#initialize(step_name, key, existing_value, incoming_value) ⇒ ParamCollisionError

Returns a new instance of ParamCollisionError.



24
25
26
27
28
29
30
# File 'lib/railsmith/pipeline/errors.rb', line 24

def initialize(step_name, key, existing_value, incoming_value)
  super(
    "Pipeline step :#{step_name} merged :#{key} but it already exists with a different value " \
    "(existing: #{existing_value.inspect}, incoming: #{incoming_value.inspect}). " \
    "Rename keys in earlier steps or use inputs: on a later step."
  )
end